
Nice small Javascript Icon Picker, forked from https://github.com/migliori/universal-icon-picker: see full documentation there.

## License

[MIT](https://choosealicense.com/licenses/mit/)

## Credits

Thanks to Gilles Migliori for his Universal Icon Picker library!
